==> HEBO-0.3.2-py3-none-any.whl: hebo/optimizers/hebo_contextual.py <==
# Copyright (C) 2020. Huawei Technologies Co., Ltd. All rights reserved.

# This program is free software; you can redistribute it and/or modify it under
# the terms of the MIT license.

# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the MIT License for more details.


import numpy as np
import pandas as pd
import torch

from .abstract_optimizer import AbstractOptimizer
from .hebo import HEBO
from hebo.acquisitions.acq import Acquisition, MACE

class HEBO_VectorContextual(AbstractOptimizer):
    support_parallel_opt  = True
    support_combinatorial = True
    support_contextual    = True
    def __init__(self, 
            space,
            context_dict : dict, 
            model_name   : str = 'gpy',
            rand_sample  : int = None
            ):
        self.hebo         = HEBO(space, model_name, rand_sample)
        self.context_dict = context_dict
        self.context      = None

    @property
    def context_vector(self) -> dict: 
        fix_input = self.context_dict[self.context]
        for k in fix_input.keys():
            assert k in self.hebo.space.para_names
        return fix_input

    def suggest(self, n):
        return self.hebo.suggest(n, fix_input = self.context_vector)

    def observe(self, X, y):
        self.hebo.observe(X, y)

    @property
    def best_x(self) -> pd.DataFrame:
        raise NotImplementedError('Not supported for contextual BO')

    @property
    def best_y(self) -> pd.DataFrame:
        raise NotImplementedError('Not supported for contextual BO')

==> HEBO-0.3.6-py3-none-any.whl: hebo/optimizers/hebo_contextual.py <==
# Copyright (C) 2020. Huawei Technologies Co., Ltd. All rights reserved.

# This program is free software; you can redistribute it and/or modify it under
# the terms of the MIT license.

# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the MIT License for more details.


import numpy as np
import pandas as pd
import torch
from hebo.acquisitions.acq import Acquisition, MACE

from .abstract_optimizer import AbstractOptimizer
from .hebo import HEBO


class HEBO_VectorContextual(AbstractOptimizer):
    support_parallel_opt = True
    support_combinatorial = True
    support_contextual = True

    def __init__(self, space, context_dict: dict, model_name: str = "gp", rand_sample: int = None):
        super().__init__(space=space, csv_save_path=None)
        self.hebo = HEBO(space, model_name, rand_sample)
        self.context_dict = context_dict
        self.context = None

    @property
    def context_vector(self) -> dict:
        fix_input = self.context_dict[self.context]
        for k in fix_input.keys():
            assert k in self.hebo.space.para_names
        return fix_input

    def suggest(self, n):
        return self.hebo.suggest(n, fix_input=self.context_vector)

    def observe_new_data(self, X, y):
        self.hebo.observe_new_data(X, y)

    @property
    def best_x(self) -> pd.DataFrame:
        raise NotImplementedError("Not supported for contextual BO")

    @property
    def best_y(self) -> pd.DataFrame:
        raise NotImplementedError("Not supported for contextual BO")
